 # Geosoup 0.1.0

Geosoup is a python package for geospatial data manipulation using GDAL and GDAL bindings in python.

This package is a minimalistic software distribution for limited manipulation of common geospatial data types such as rasters, vectors and samples. All the heavy lifting is done by GDAL, numpy and, scipy. 

Install using:

`pip install geosoup`


